Struct amazon_sp_aplus_content::models::standard_image_sidebar_module::StandardImageSidebarModule
source · [−]pub struct StandardImageSidebarModule {
pub headline: Option<Box<TextComponent>>,
pub image_caption_block: Option<Box<StandardImageCaptionBlock>>,
pub description_text_block: Option<Box<StandardTextBlock>>,
pub description_list_block: Option<Box<StandardTextListBlock>>,
pub sidebar_image_text_block: Option<Box<StandardImageTextBlock>>,
pub sidebar_list_block: Option<Box<StandardTextListBlock>>,
}Expand description
StandardImageSidebarModule : Two images, two paragraphs, and two bulleted lists. One image is smaller and displayed in the sidebar.
Fields
headline: Option<Box<TextComponent>>image_caption_block: Option<Box<StandardImageCaptionBlock>>description_text_block: Option<Box<StandardTextBlock>>description_list_block: Option<Box<StandardTextListBlock>>Implementations
sourceimpl StandardImageSidebarModule
impl StandardImageSidebarModule
sourcepub fn new() -> StandardImageSidebarModule
pub fn new() -> StandardImageSidebarModule
Two images, two paragraphs, and two bulleted lists. One image is smaller and displayed in the sidebar.